---
sidebar_position: 2
---

The following diagram shows the overall system components of the Unstract platform. Please note that this documentation will focus on the SDK component of the platform. The SDK component is the component that allows the users to create their own Tools for use in the platform. The SDK and the platform abstracts away the complexities of the underlying components and allows the users to focus on the business logic of their Tools.

As you can see from the diagram, the SDKs can be used to create **Tools** and **Applications**. Tools can be used in the Workflows created in the platform. Applications or Apps are standalone and secure. Apps can be used to provide Q&A (RAG) capabilities over unstructured sources. Apps are not limited to Q&A and can be used to provide any other capabilities that can use the platform's indexer and related LLM features.

![platform components](/img/page_content/platform_components.png)
